pub fn emit_deletion_event<B>(event: B::Event) -> EmitEvent<B>where
    B: EventSourcedBehavior + Send + Sync + 'static,
An effect to emit an event upon having successfully handed it off to be persisted. The event will be flagged to represent the deletion of an entity instance.